..
    Copyright (C) 2022 CERN.

    Invenio-Users-Resources is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.


.. include:: ../CHANGES.rst
